@@ -217,6 +217,7 @@ var searchData=
   ['functioncategory',['FunctionCategory',['../namespacecom_1_1sun_1_1star_1_1sheet_1_1FunctionCategory.html',1,'com::sun::star::sheet']]],
   ['gallery',['gallery',['../namespacecom_1_1sun_1_1star_1_1gallery.html',1,'com::sun::star']]],
   ['galleryitemtype',['GalleryItemType',['../namespacecom_1_1sun_1_1star_1_1gallery_1_1GalleryItemType.html',1,'com::sun::star::gallery']]],
+  ['generalfunction2',['GeneralFunction2',['../namespacecom_1_1sun_1_1star_1_1sheet_1_1GeneralFunction2.html',1,'com::sun::star::sheet']]],
   ['geometry',['geometry',['../namespacecom_1_1sun_1_1star_1_1geometry.html',1,'com::sun::star']]],
   ['graphic',['graphic',['../namespacecom_1_1sun_1_1star_1_1graphic.html',1,'com::sun::star']]],
   ['graphiccolormode',['GraphicColorMode',['../namespacecom_1_1sun_1_1star_1_1graphic_1_1GraphicColorMode.html',1,'com::sun::star::graphic']]],
@@ -407,7 +408,7 @@ var searchData=
   ['task',['task',['../namespacecom_1_1sun_1_1star_1_1task.html',1,'com::sun::star']]],
   ['templatedescription',['TemplateDescription',['../namespacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1TemplateDescription.html',1,'com::sun::star::ui::dialogs']]],
   ['templatedisplayformat',['TemplateDisplayFormat',['../namespacecom_1_1sun_1_1star_1_1text_1_1TemplateDisplayFormat.html',1,'com::sun::star::text']]],
-  ['test',['test',['../namespacecom_1_1sun_1_1star_1_1deployment_1_1test.html',1,'com::sun::star::deployment']]],
+  ['test',['test',['../namespacecom_1_1sun_1_1star_1_1deployment_1_1test.html',1,'com::sun::star::deployment::test'],['../namespacecom_1_1sun_1_1star_1_1ui_1_1test.html',1,'com::sun::star::ui::test']]],
   ['text',['text',['../namespacecom_1_1sun_1_1star_1_1text.html',1,'com::sun::star']]],
   ['textalign',['TextAlign',['../namespacecom_1_1sun_1_1star_1_1awt_1_1TextAlign.html',1,'com::sun::star::awt']]],
   ['textanimationtype',['TextAnimationType',['../namespacecom_1_1sun_1_1star_1_1presentation_1_1TextAnimationType.html',1,'com::sun::star::presentation']]],
